// Copyright (c) 2000  David Muse
// See the file COPYING for more information.

char	*databaselist[]={
	"oracle8",
	"mysql",
	"postgresql",
	"sqlite",
	"freetds",
	"sybase",
	"db2",
	"firebird",
	"odbc",
	"mdbtools",
	(char *)NULL
};
